Dashboard | edX

Skip to main content
Help

## edX Help

Have general questions about edX? You can find lots of helpful information in the edX FAQ.

Have a question about something specific? You can contact the edX general support team directly:

Report a problem Make a suggestion Ask a question

Please note: The edX support team is English speaking. While we will do our best to address your inquiry in any language, our responses will be in English.

Briefly describe your issue* Tell us the details* Include error messages, steps which lead to the issue, etc

## Thank You!

Thank you for your inquiry or feedback. We typically respond to a request within one business day (Monday to Friday, 13:00 UTC to 21:00 UTC.) In the meantime, please review our detailed FAQs where most questions have already been answered.

## Current Courses

- Enrolled as:
  Honor Code

  ### Advanced Spanish Language and Culture

  SMES - ASLCx Ended - May 12, 2015
  View Archived Course Advanced Spanish Language and Culture
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Honor Code

  ### Essential Human Biology: Cells and Tissues

  AdelaideX - HumBio101x Starts - Jun 10, 2015
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Honor Code

  ### The World of Wine

  AdelaideX - Wine101x Starts - June 10, 2015- Self-Paced
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Honor Code

  ### Becoming a Resilient Person: The Science of Stress Management and Promoting Wellbeing

  UWashingtonX - ECFS311x Started - Jun 02, 2015
  View Course Becoming a Resilient Person: The Science of Stress Management and Promoting Wellbeing
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Honor Code

  ### Programming with C#

  Microsoft - DEV204x Started - Jun 02, 2015
  View Course Programming with C#
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Honor Code

  ### Introduction to Cloud Computing

  IEEEx - CloudIntro.x Started - Jun 03, 2015
  View Course Introduction to Cloud Computing
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Honor Code

  ### The Analytics Edge

  MITx - 15.071x Started - Jun 02, 2015
  View Course The Analytics Edge
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Honor Code

  ### Intermediate Chinese grammar 中级汉语语法

  PekingX - 20000001x Started - Mar 16, 2015
  View Course Intermediate Chinese grammar 中级汉语语法
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Honor Code

  ### Demo Course

  edX - DemoX.1 Started - Aug 01, 2014
  View Course Demo Course
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Honor Code

  ### Vocal Recording Technology

  BerkleeX - BMPR365x Ended - Jun 03, 2015
  View Archived Course Vocal Recording Technology
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Honor Code

  ### Science & Cooking: From Haute Cuisine to Soft Matter Science

  HarvardX - SPU27x Starts - Jun 17, 2015
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Honor Code

  ### Scalable Machine Learning

  BerkeleyX - CS190.1x Starts - Jun 29, 2015
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Honor Code

  ### Introduction to Big Data with Apache Spark

  BerkeleyX - CS100.1x Started - Jun 01, 2015
  View Course Introduction to Big Data with Apache Spark
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Honor Code

  ### Introduction to Linux

  LinuxFoundationX - LFS101x.2 Started - Jan 05, 2015
  View Course Introduction to Linux
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Auditing

  ### Introduction to Functional Programming

  DelftX - FP101x Ended - Dec 31, 2014
  View Archived Course Introduction to Functional Programming
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Honor Code

  ### Science & Cooking: From Haute Cuisine to Soft Matter Science

  HarvardX - SPU27x Ended - Mar 16, 2014
  View Archived Course Science & Cooking: From Haute Cuisine to Soft Matter Science
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Honor Code

  ### Introduction to Statistics: Descriptive Statistics

  BerkeleyX - Stat2.1x Ended - Apr 01, 2013
  View Archived Course Introduction to Statistics: Descriptive Statistics
  Course options dropdown
  - Unenroll
  - Email Settings
- Enrolled as:
  Honor Code

  ### Foundations of Computer Graphics

  BerkeleyX - CS184.1x Ended - Dec 21, 2012
  View Archived Course Foundations of Computer Graphics
  Course options dropdown
  - Unenroll

## Email Settings for , window open

Receive course emails

## , window open